/*******************************************************************************
* File Name: SER_PINS.h
* Version 3.0
*
* Description:
*  This file provides constants and parameter values for the pin components
*  buried into SCB Component.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PINS_SER_H)
#define CY_SCB_PINS_SER_H

#include "cydevice_trm.h"
#include "cyfitter.h"
#include "cytypes.h"


/***************************************
*   Conditional Compilation Parameters
****************************************/

/* Unconfigured pins */
#define SER_REMOVE_RX_WAKE_SCL_MOSI_PIN  (1u)
#define SER_REMOVE_RX_SCL_MOSI_PIN      (1u)
#define SER_REMOVE_TX_SDA_MISO_PIN      (1u)
#define SER_REMOVE_SCLK_PIN      (1u)
#define SER_REMOVE_SS0_PIN      (1u)
#define SER_REMOVE_SS1_PIN                 (1u)
#define SER_REMOVE_SS2_PIN                 (1u)
#define SER_REMOVE_SS3_PIN                 (1u)

/* Mode defined pins */
#define SER_REMOVE_I2C_PINS                (1u)
#define SER_REMOVE_SPI_MASTER_PINS         (1u)
#define SER_REMOVE_SPI_MASTER_SCLK_PIN     (1u)
#define SER_REMOVE_SPI_MASTER_MOSI_PIN     (1u)
#define SER_REMOVE_SPI_MASTER_MISO_PIN     (1u)
#define SER_REMOVE_SPI_MASTER_SS0_PIN      (1u)
#define SER_REMOVE_SPI_MASTER_SS1_PIN      (1u)
#define SER_REMOVE_SPI_MASTER_SS2_PIN      (1u)
#define SER_REMOVE_SPI_MASTER_SS3_PIN      (1u)
#define SER_REMOVE_SPI_SLAVE_PINS          (1u)
#define SER_REMOVE_SPI_SLAVE_MOSI_PIN      (1u)
#define SER_REMOVE_SPI_SLAVE_MISO_PIN      (1u)
#define SER_REMOVE_UART_TX_PIN             (0u)
#define SER_REMOVE_UART_RX_TX_PIN          (1u)
#define SER_REMOVE_UART_RX_PIN             (0u)
#define SER_REMOVE_UART_RX_WAKE_PIN        (1u)
#define SER_REMOVE_UART_RTS_PIN            (1u)
#define SER_REMOVE_UART_CTS_PIN            (1u)

/* Unconfigured pins */
#define SER_RX_WAKE_SCL_MOSI_PIN (0u == SER_REMOVE_RX_WAKE_SCL_MOSI_PIN)
#define SER_RX_SCL_MOSI_PIN     (0u == SER_REMOVE_RX_SCL_MOSI_PIN)
#define SER_TX_SDA_MISO_PIN     (0u == SER_REMOVE_TX_SDA_MISO_PIN)
#define SER_SCLK_PIN     (0u == SER_REMOVE_SCLK_PIN)
#define SER_SS0_PIN     (0u == SER_REMOVE_SS0_PIN)
#define SER_SS1_PIN                (0u == SER_REMOVE_SS1_PIN)
#define SER_SS2_PIN                (0u == SER_REMOVE_SS2_PIN)
#define SER_SS3_PIN                (0u == SER_REMOVE_SS3_PIN)

/* Mode defined pins */
#define SER_I2C_PINS               (0u == SER_REMOVE_I2C_PINS)
#define SER_SPI_MASTER_PINS        (0u == SER_REMOVE_SPI_MASTER_PINS)
#define SER_SPI_MASTER_SCLK_PIN    (0u == SER_REMOVE_SPI_MASTER_SCLK_PIN)
#define SER_SPI_MASTER_MOSI_PIN    (0u == SER_REMOVE_SPI_MASTER_MOSI_PIN)
#define SER_SPI_MASTER_MISO_PIN    (0u == SER_REMOVE_SPI_MASTER_MISO_PIN)
#define SER_SPI_MASTER_SS0_PIN     (0u == SER_REMOVE_SPI_MASTER_SS0_PIN)
#define SER_SPI_MASTER_SS1_PIN     (0u == SER_REMOVE_SPI_MASTER_SS1_PIN)
#define SER_SPI_MASTER_SS2_PIN     (0u == SER_REMOVE_SPI_MASTER_SS2_PIN)
#define SER_SPI_MASTER_SS3_PIN     (0u == SER_REMOVE_SPI_MASTER_SS3_PIN)
#define SER_SPI_SLAVE_PINS         (0u == SER_REMOVE_SPI_SLAVE_PINS)
#define SER_SPI_SLAVE_MOSI_PIN     (0u == SER_REMOVE_SPI_SLAVE_MOSI_PIN)
#define SER_SPI_SLAVE_MISO_PIN     (0u == SER_REMOVE_SPI_SLAVE_MISO_PIN)
#define SER_UART_TX_PIN            (0u == SER_REMOVE_UART_TX_PIN)
#define SER_UART_RX_TX_PIN         (0u == SER_REMOVE_UART_RX_TX_PIN)
#define SER_UART_RX_PIN            (0u == SER_REMOVE_UART_RX_PIN)
#define SER_UART_RX_WAKE_PIN       (0u == SER_REMOVE_UART_RX_WAKE_PIN)
#define SER_UART_RTS_PIN           (0u == SER_REMOVE_UART_RTS_PIN)
#define SER_UART_CTS_PIN           (0u == SER_REMOVE_UART_CTS_PIN)


/***************************************
*             Includes
****************************************/

#if (SER_RX_WAKE_SCL_MOSI_PIN)
    #include "SER_uart_rx_wake_i2c_scl_spi_mosi.h"
#endif /* (SER_RX_SCL_MOSI) */

#if (SER_RX_SCL_MOSI_PIN)
    #include "SER_uart_rx_i2c_scl_spi_mosi.h"
#endif /* (SER_RX_SCL_MOSI) */

#if (SER_TX_SDA_MISO_PIN)
    #include "SER_uart_tx_i2c_sda_spi_miso.h"
#endif /* (SER_TX_SDA_MISO) */

#if (SER_SCLK_PIN)
    #include "SER_spi_sclk.h"
#endif /* (SER_SCLK) */

#if (SER_SS0_PIN)
    #include "SER_spi_ss0.h"
#endif /* (SER_SS0_PIN) */

#if (SER_SS1_PIN)
    #include "SER_spi_ss1.h"
#endif /* (SER_SS1_PIN) */

#if (SER_SS2_PIN)
    #include "SER_spi_ss2.h"
#endif /* (SER_SS2_PIN) */

#if (SER_SS3_PIN)
    #include "SER_spi_ss3.h"
#endif /* (SER_SS3_PIN) */

#if (SER_I2C_PINS)
    #include "SER_scl.h"
    #include "SER_sda.h"
#endif /* (SER_I2C_PINS) */

#if (SER_SPI_MASTER_PINS)
#if (SER_SPI_MASTER_SCLK_PIN)
    #include "SER_sclk_m.h"
#endif /* (SER_SPI_MASTER_SCLK_PIN) */

#if (SER_SPI_MASTER_MOSI_PIN)
    #include "SER_mosi_m.h"
#endif /* (SER_SPI_MASTER_MOSI_PIN) */

#if (SER_SPI_MASTER_MISO_PIN)
    #include "SER_miso_m.h"
#endif /*(SER_SPI_MASTER_MISO_PIN) */
#endif /* (SER_SPI_MASTER_PINS) */

#if (SER_SPI_SLAVE_PINS)
    #include "SER_sclk_s.h"
    #include "SER_ss_s.h"

#if (SER_SPI_SLAVE_MOSI_PIN)
    #include "SER_mosi_s.h"
#endif /* (SER_SPI_SLAVE_MOSI_PIN) */

#if (SER_SPI_SLAVE_MISO_PIN)
    #include "SER_miso_s.h"
#endif /*(SER_SPI_SLAVE_MISO_PIN) */
#endif /* (SER_SPI_SLAVE_PINS) */

#if (SER_SPI_MASTER_SS0_PIN)
    #include "SER_ss0_m.h"
#endif /* (SER_SPI_MASTER_SS0_PIN) */

#if (SER_SPI_MASTER_SS1_PIN)
    #include "SER_ss1_m.h"
#endif /* (SER_SPI_MASTER_SS1_PIN) */

#if (SER_SPI_MASTER_SS2_PIN)
    #include "SER_ss2_m.h"
#endif /* (SER_SPI_MASTER_SS2_PIN) */

#if (SER_SPI_MASTER_SS3_PIN)
    #include "SER_ss3_m.h"
#endif /* (SER_SPI_MASTER_SS3_PIN) */

#if (SER_UART_TX_PIN)
    #include "SER_tx.h"
#endif /* (SER_UART_TX_PIN) */

#if (SER_UART_RX_TX_PIN)
    #include "SER_rx_tx.h"
#endif /* (SER_UART_RX_TX_PIN) */

#if (SER_UART_RX_PIN)
    #include "SER_rx.h"
#endif /* (SER_UART_RX_PIN) */

#if (SER_UART_RX_WAKE_PIN)
    #include "SER_rx_wake.h"
#endif /* (SER_UART_RX_WAKE_PIN) */

#if (SER_UART_RTS_PIN)
    #include "SER_rts.h"
#endif /* (SER_UART_RTS_PIN) */

#if (SER_UART_CTS_PIN)
    #include "SER_cts.h"
#endif /* (SER_UART_CTS_PIN) */


/***************************************
*              Registers
***************************************/

#if (SER_RX_WAKE_SCL_MOSI_PIN)
    #define SER_RX_WAKE_SCL_MOSI_HSIOM_REG \
                            (*(reg32 *) SER_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM)
    #define SER_RX_WAKE_SCL_MOSI_HSIOM_PTR \
                            ( (reg32 *) SER_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM)
    #define SER_RX_WAKE_SCL_MOSI_HSIOM_MASK \
                            (SER_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_MASK)
    #define SER_RX_WAKE_SCL_MOSI_HSIOM_POS \
                            (SER_uart_rx_wake_i2c_scl_spi_mosi__0__HSIOM_SHIFT)

    #define SER_RX_WAKE_SCL_MOSI_INTCFG_REG \
                            (*(reg32 *) SER_uart_rx_wake_i2c_scl_spi_mosi__0__INTCFG)
    #define SER_RX_WAKE_SCL_MOSI_INTCFG_PTR \
                            ( (reg32 *) SER_uart_rx_wake_i2c_scl_spi_mosi__0__INTCFG)
    #define SER_RX_WAKE_SCL_MOSI_INTCFG_TYPE_POS  (SER_uart_rx_wake_i2c_scl_spi_mosi__SHIFT)
    #define SER_RX_WAKE_SCL_MOSI_INTCFG_TYPE_MASK \
                            ((uint32) SER_INTCFG_TYPE_MASK << \
                                      SER_RX_WAKE_SCL_MOSI_INTCFG_TYPE_POS)
#endif /* (SER_RX_WAKE_SCL_MOSI_PIN) */

#if (SER_RX_SCL_MOSI_PIN)
    #define SER_RX_SCL_MOSI_HSIOM_REG   (*(reg32 *) SER_uart_rx_i2c_scl_spi_mosi__0__HSIOM)
    #define SER_RX_SCL_MOSI_HSIOM_PTR   ( (reg32 *) SER_uart_rx_i2c_scl_spi_mosi__0__HSIOM)
    #define SER_RX_SCL_MOSI_HSIOM_MASK  (SER_uart_rx_i2c_scl_spi_mosi__0__HSIOM_MASK)
    #define SER_RX_SCL_MOSI_HSIOM_POS   (SER_uart_rx_i2c_scl_spi_mosi__0__HSIOM_SHIFT)
#endif /* (SER_RX_SCL_MOSI_PIN) */

#if (SER_TX_SDA_MISO_PIN)
    #define SER_TX_SDA_MISO_HSIOM_REG   (*(reg32 *) SER_uart_tx_i2c_sda_spi_miso__0__HSIOM)
    #define SER_TX_SDA_MISO_HSIOM_PTR   ( (reg32 *) SER_uart_tx_i2c_sda_spi_miso__0__HSIOM)
    #define SER_TX_SDA_MISO_HSIOM_MASK  (SER_uart_tx_i2c_sda_spi_miso__0__HSIOM_MASK)
    #define SER_TX_SDA_MISO_HSIOM_POS   (SER_uart_tx_i2c_sda_spi_miso__0__HSIOM_SHIFT)
#endif /* (SER_TX_SDA_MISO_PIN) */

#if (SER_SCLK_PIN)
    #define SER_SCLK_HSIOM_REG   (*(reg32 *) SER_spi_sclk__0__HSIOM)
    #define SER_SCLK_HSIOM_PTR   ( (reg32 *) SER_spi_sclk__0__HSIOM)
    #define SER_SCLK_HSIOM_MASK  (SER_spi_sclk__0__HSIOM_MASK)
    #define SER_SCLK_HSIOM_POS   (SER_spi_sclk__0__HSIOM_SHIFT)
#endif /* (SER_SCLK_PIN) */

#if (SER_SS0_PIN)
    #define SER_SS0_HSIOM_REG   (*(reg32 *) SER_spi_ss0__0__HSIOM)
    #define SER_SS0_HSIOM_PTR   ( (reg32 *) SER_spi_ss0__0__HSIOM)
    #define SER_SS0_HSIOM_MASK  (SER_spi_ss0__0__HSIOM_MASK)
    #define SER_SS0_HSIOM_POS   (SER_spi_ss0__0__HSIOM_SHIFT)
#endif /* (SER_SS0_PIN) */

#if (SER_SS1_PIN)
    #define SER_SS1_HSIOM_REG      (*(reg32 *) SER_spi_ss1__0__HSIOM)
    #define SER_SS1_HSIOM_PTR      ( (reg32 *) SER_spi_ss1__0__HSIOM)
    #define SER_SS1_HSIOM_MASK     (SER_spi_ss1__0__HSIOM_MASK)
    #define SER_SS1_HSIOM_POS      (SER_spi_ss1__0__HSIOM_SHIFT)
#endif /* (SER_SS1_PIN) */

#if (SER_SS2_PIN)
    #define SER_SS2_HSIOM_REG     (*(reg32 *) SER_spi_ss2__0__HSIOM)
    #define SER_SS2_HSIOM_PTR     ( (reg32 *) SER_spi_ss2__0__HSIOM)
    #define SER_SS2_HSIOM_MASK    (SER_spi_ss2__0__HSIOM_MASK)
    #define SER_SS2_HSIOM_POS     (SER_spi_ss2__0__HSIOM_SHIFT)
#endif /* (SER_SS2_PIN) */

#if (SER_SS3_PIN)
    #define SER_SS3_HSIOM_REG     (*(reg32 *) SER_spi_ss3__0__HSIOM)
    #define SER_SS3_HSIOM_PTR     ( (reg32 *) SER_spi_ss3__0__HSIOM)
    #define SER_SS3_HSIOM_MASK    (SER_spi_ss3__0__HSIOM_MASK)
    #define SER_SS3_HSIOM_POS     (SER_spi_ss3__0__HSIOM_SHIFT)
#endif /* (SER_SS3_PIN) */

#if (SER_I2C_PINS)
    #define SER_SCL_HSIOM_REG     (*(reg32 *) SER_scl__0__HSIOM)
    #define SER_SCL_HSIOM_PTR     ( (reg32 *) SER_scl__0__HSIOM)
    #define SER_SCL_HSIOM_MASK    (SER_scl__0__HSIOM_MASK)
    #define SER_SCL_HSIOM_POS     (SER_scl__0__HSIOM_SHIFT)

    #define SER_SDA_HSIOM_REG     (*(reg32 *) SER_sda__0__HSIOM)
    #define SER_SDA_HSIOM_PTR     ( (reg32 *) SER_sda__0__HSIOM)
    #define SER_SDA_HSIOM_MASK    (SER_sda__0__HSIOM_MASK)
    #define SER_SDA_HSIOM_POS     (SER_sda__0__HSIOM_SHIFT)
#endif /* (SER_I2C_PINS) */

#if (SER_SPI_MASTER_SCLK_PIN)
    #define SER_SCLK_M_HSIOM_REG   (*(reg32 *) SER_sclk_m__0__HSIOM)
    #define SER_SCLK_M_HSIOM_PTR   ( (reg32 *) SER_sclk_m__0__HSIOM)
    #define SER_SCLK_M_HSIOM_MASK  (SER_sclk_m__0__HSIOM_MASK)
    #define SER_SCLK_M_HSIOM_POS   (SER_sclk_m__0__HSIOM_SHIFT)
#endif /* (SER_SPI_MASTER_SCLK_PIN) */

#if (SER_SPI_MASTER_SS0_PIN)
    #define SER_SS0_M_HSIOM_REG    (*(reg32 *) SER_ss0_m__0__HSIOM)
    #define SER_SS0_M_HSIOM_PTR    ( (reg32 *) SER_ss0_m__0__HSIOM)
    #define SER_SS0_M_HSIOM_MASK   (SER_ss0_m__0__HSIOM_MASK)
    #define SER_SS0_M_HSIOM_POS    (SER_ss0_m__0__HSIOM_SHIFT)
#endif /* (SER_SPI_MASTER_SS0_PIN) */

#if (SER_SPI_MASTER_SS1_PIN)
    #define SER_SS1_M_HSIOM_REG    (*(reg32 *) SER_ss1_m__0__HSIOM)
    #define SER_SS1_M_HSIOM_PTR    ( (reg32 *) SER_ss1_m__0__HSIOM)
    #define SER_SS1_M_HSIOM_MASK   (SER_ss1_m__0__HSIOM_MASK)
    #define SER_SS1_M_HSIOM_POS    (SER_ss1_m__0__HSIOM_SHIFT)
#endif /* (SER_SPI_MASTER_SS1_PIN) */

#if (SER_SPI_MASTER_SS2_PIN)
    #define SER_SS2_M_HSIOM_REG    (*(reg32 *) SER_ss2_m__0__HSIOM)
    #define SER_SS2_M_HSIOM_PTR    ( (reg32 *) SER_ss2_m__0__HSIOM)
    #define SER_SS2_M_HSIOM_MASK   (SER_ss2_m__0__HSIOM_MASK)
    #define SER_SS2_M_HSIOM_POS    (SER_ss2_m__0__HSIOM_SHIFT)
#endif /* (SER_SPI_MASTER_SS2_PIN) */

#if (SER_SPI_MASTER_SS3_PIN)
    #define SER_SS3_M_HSIOM_REG    (*(reg32 *) SER_ss3_m__0__HSIOM)
    #define SER_SS3_M_HSIOM_PTR    ( (reg32 *) SER_ss3_m__0__HSIOM)
    #define SER_SS3_M_HSIOM_MASK   (SER_ss3_m__0__HSIOM_MASK)
    #define SER_SS3_M_HSIOM_POS    (SER_ss3_m__0__HSIOM_SHIFT)
#endif /* (SER_SPI_MASTER_SS3_PIN) */

#if (SER_UART_TX_PIN)
    #define SER_TX_HSIOM_REG   (*(reg32 *) SER_tx__0__HSIOM)
    #define SER_TX_HSIOM_PTR   ( (reg32 *) SER_tx_0__HSIOM)
    #define SER_TX_HSIOM_MASK  (SER_tx__0__HSIOM_MASK)
    #define SER_TX_HSIOM_POS   (SER_tx__0__HSIOM_SHIFT)
#endif /* (SER_UART_TX_PIN) */

#if (SER_UART_RTS_PIN)
    #define SER_RTS_HSIOM_REG  (*(reg32 *) SER_rts__0__HSIOM)
    #define SER_RTS_HSIOM_PTR  ( (reg32 *) SER_rts__0__HSIOM)
    #define SER_RTS_HSIOM_MASK (SER_rts__0__HSIOM_MASK)
    #define SER_RTS_HSIOM_POS  (SER_rts__0__HSIOM_SHIFT)
#endif /* (SER_UART_RTS_PIN) */


/***************************************
*        Registers Constants
***************************************/

/* Pins constants */
#define SER_HSIOM_DEF_SEL      (0x00u)
#define SER_HSIOM_GPIO_SEL     (0x00u)
#define SER_HSIOM_UART_SEL     (0x09u)
#define SER_HSIOM_I2C_SEL      (0x0Eu)
#define SER_HSIOM_SPI_SEL      (0x0Fu)

#define SER_RX_WAKE_SCL_MOSI_PIN_INDEX   (0u)
#define SER_RX_SCL_MOSI_PIN_INDEX       (0u)
#define SER_TX_SDA_MISO_PIN_INDEX       (1u)
#define SER_SCLK_PIN_INDEX       (2u)
#define SER_SS0_PIN_INDEX       (3u)
#define SER_SS1_PIN_INDEX                  (4u)
#define SER_SS2_PIN_INDEX                  (5u)
#define SER_SS3_PIN_INDEX                  (6u)

#define SER_RX_WAKE_SCL_MOSI_PIN_MASK ((uint32) 0x01u << SER_RX_WAKE_SCL_MOSI_PIN_INDEX)
#define SER_RX_SCL_MOSI_PIN_MASK     ((uint32) 0x01u << SER_RX_SCL_MOSI_PIN_INDEX)
#define SER_TX_SDA_MISO_PIN_MASK     ((uint32) 0x01u << SER_TX_SDA_MISO_PIN_INDEX)
#define SER_SCLK_PIN_MASK     ((uint32) 0x01u << SER_SCLK_PIN_INDEX)
#define SER_SS0_PIN_MASK     ((uint32) 0x01u << SER_SS0_PIN_INDEX)
#define SER_SS1_PIN_MASK                ((uint32) 0x01u << SER_SS1_PIN_INDEX)
#define SER_SS2_PIN_MASK                ((uint32) 0x01u << SER_SS2_PIN_INDEX)
#define SER_SS3_PIN_MASK                ((uint32) 0x01u << SER_SS3_PIN_INDEX)

/* Pin interrupt constants */
#define SER_INTCFG_TYPE_MASK           (0x03u)
#define SER_INTCFG_TYPE_FALLING_EDGE   (0x02u)

/* Pin Drive Mode constants */
#define SER_PIN_DM_ALG_HIZ  (0u)
#define SER_PIN_DM_DIG_HIZ  (1u)
#define SER_PIN_DM_OD_LO    (4u)
#define SER_PIN_DM_STRONG   (6u)


/***************************************
*          Macro Definitions
***************************************/

/* Return drive mode of the pin */
#define SER_DM_MASK    (0x7u)
#define SER_DM_SIZE    (3)
#define SER_GET_P4_PIN_DM(reg, pos) \
    ( ((reg) & (uint32) ((uint32) SER_DM_MASK << (SER_DM_SIZE * (pos)))) >> \
                                                              (SER_DM_SIZE * (pos)) )

#if (SER_TX_SDA_MISO_PIN)
    #define SER_CHECK_TX_SDA_MISO_PIN_USED \
                (SER_PIN_DM_ALG_HIZ != \
                    SER_GET_P4_PIN_DM(SER_uart_tx_i2c_sda_spi_miso_PC, \
                                                   SER_uart_tx_i2c_sda_spi_miso_SHIFT))
#endif /* (SER_TX_SDA_MISO_PIN) */

#if (SER_SS0_PIN)
    #define SER_CHECK_SS0_PIN_USED \
                (SER_PIN_DM_ALG_HIZ != \
                    SER_GET_P4_PIN_DM(SER_spi_ss0_PC, \
                                                   SER_spi_ss0_SHIFT))
#endif /* (SER_SS0_PIN) */

/* Set bits-mask in register */
#define SER_SET_REGISTER_BITS(reg, mask, pos, mode) \
                    do                                           \
                    {                                            \
                        (reg) = (((reg) & ((uint32) ~(uint32) (mask))) | ((uint32) ((uint32) (mode) << (pos)))); \
                    }while(0)

/* Set bit in the register */
#define SER_SET_REGISTER_BIT(reg, mask, val) \
                    ((val) ? ((reg) |= (mask)) : ((reg) &= ((uint32) ~((uint32) (mask)))))

#define SER_SET_HSIOM_SEL(reg, mask, pos, sel) SER_SET_REGISTER_BITS(reg, mask, pos, sel)
#define SER_SET_INCFG_TYPE(reg, mask, pos, intType) \
                                                        SER_SET_REGISTER_BITS(reg, mask, pos, intType)
#define SER_SET_INP_DIS(reg, mask, val) SER_SET_REGISTER_BIT(reg, mask, val)

/* SER_SET_I2C_SCL_DR(val) - Sets I2C SCL DR register.
*  SER_SET_I2C_SCL_HSIOM_SEL(sel) - Sets I2C SCL HSIOM settings.
*/
/* SCB I2C: scl signal */
#if (SER_CY_SCBIP_V0)
#if (SER_I2C_PINS)
    #define SER_SET_I2C_SCL_DR(val) SER_scl_Write(val)

    #define SER_SET_I2C_SCL_HSIOM_SEL(sel) \
                          SER_SET_HSIOM_SEL(SER_SCL_HSIOM_REG,  \
                                                         SER_SCL_HSIOM_MASK, \
                                                         SER_SCL_HSIOM_POS,  \
                                                         (sel))
    #define SER_WAIT_SCL_SET_HIGH  (0u == SER_scl_Read())

/* Unconfigured SCB: scl signal */
#elif (SER_RX_WAKE_SCL_MOSI_PIN)
    #define SER_SET_I2C_SCL_DR(val) \
                            SER_uart_rx_wake_i2c_scl_spi_mosi_Write(val)

    #define SER_SET_I2C_SCL_HSIOM_SEL(sel) \
                    SER_SET_HSIOM_SEL(SER_RX_WAKE_SCL_MOSI_HSIOM_REG,  \
                                                   SER_RX_WAKE_SCL_MOSI_HSIOM_MASK, \
                                                   SER_RX_WAKE_SCL_MOSI_HSIOM_POS,  \
                                                   (sel))

    #define SER_WAIT_SCL_SET_HIGH  (0u == SER_uart_rx_wake_i2c_scl_spi_mosi_Read())

#elif (SER_RX_SCL_MOSI_PIN)
    #define SER_SET_I2C_SCL_DR(val) \
                            SER_uart_rx_i2c_scl_spi_mosi_Write(val)


    #define SER_SET_I2C_SCL_HSIOM_SEL(sel) \
                            SER_SET_HSIOM_SEL(SER_RX_SCL_MOSI_HSIOM_REG,  \
                                                           SER_RX_SCL_MOSI_HSIOM_MASK, \
                                                           SER_RX_SCL_MOSI_HSIOM_POS,  \
                                                           (sel))

    #define SER_WAIT_SCL_SET_HIGH  (0u == SER_uart_rx_i2c_scl_spi_mosi_Read())

#else
    #define SER_SET_I2C_SCL_DR(val) \
                                                    do{ /* Does nothing */ }while(0)
    #define SER_SET_I2C_SCL_HSIOM_SEL(sel) \
                                                    do{ /* Does nothing */ }while(0)

    #define SER_WAIT_SCL_SET_HIGH  (0u)
#endif /* (SER_I2C_PINS) */

/* SCB I2C: sda signal */
#if (SER_I2C_PINS)
    #define SER_WAIT_SDA_SET_HIGH  (0u == SER_sda_Read())
/* Unconfigured SCB: sda signal */
#elif (SER_TX_SDA_MISO_PIN)
    #define SER_WAIT_SDA_SET_HIGH  (0u == SER_uart_tx_i2c_sda_spi_miso_Read())
#else
    #define SER_WAIT_SDA_SET_HIGH  (0u)
#endif /* (SER_MOSI_SCL_RX_PIN) */
#endif /* (SER_CY_SCBIP_V0) */


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Unconfigured pins */
#define SER_REMOVE_MOSI_SCL_RX_WAKE_PIN    SER_REMOVE_RX_WAKE_SCL_MOSI_PIN
#define SER_REMOVE_MOSI_SCL_RX_PIN         SER_REMOVE_RX_SCL_MOSI_PIN
#define SER_REMOVE_MISO_SDA_TX_PIN         SER_REMOVE_TX_SDA_MISO_PIN
#ifndef SER_REMOVE_SCLK_PIN
#define SER_REMOVE_SCLK_PIN                SER_REMOVE_SCLK_PIN
#endif /* SER_REMOVE_SCLK_PIN */
#ifndef SER_REMOVE_SS0_PIN
#define SER_REMOVE_SS0_PIN                 SER_REMOVE_SS0_PIN
#endif /* SER_REMOVE_SS0_PIN */

/* Unconfigured pins */
#define SER_MOSI_SCL_RX_WAKE_PIN   SER_RX_WAKE_SCL_MOSI_PIN
#define SER_MOSI_SCL_RX_PIN        SER_RX_SCL_MOSI_PIN
#define SER_MISO_SDA_TX_PIN        SER_TX_SDA_MISO_PIN
#ifndef SER_SCLK_PIN
#define SER_SCLK_PIN               SER_SCLK_PIN
#endif /* SER_SCLK_PIN */
#ifndef SER_SS0_PIN
#define SER_SS0_PIN                SER_SS0_PIN
#endif /* SER_SS0_PIN */

#if (SER_MOSI_SCL_RX_WAKE_PIN)
    #define SER_MOSI_SCL_RX_WAKE_HSIOM_REG     SER_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define SER_MOSI_SCL_RX_WAKE_HSIOM_PTR     SER_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define SER_MOSI_SCL_RX_WAKE_HSIOM_MASK    SER_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define SER_MOSI_SCL_RX_WAKE_HSIOM_POS     SER_RX_WAKE_SCL_MOSI_HSIOM_REG

    #define SER_MOSI_SCL_RX_WAKE_INTCFG_REG    SER_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define SER_MOSI_SCL_RX_WAKE_INTCFG_PTR    SER_RX_WAKE_SCL_MOSI_HSIOM_REG

    #define SER_MOSI_SCL_RX_WAKE_INTCFG_TYPE_POS   SER_RX_WAKE_SCL_MOSI_HSIOM_REG
    #define SER_MOSI_SCL_RX_WAKE_INTCFG_TYPE_MASK  SER_RX_WAKE_SCL_MOSI_HSIOM_REG
#endif /* (SER_RX_WAKE_SCL_MOSI_PIN) */

#if (SER_MOSI_SCL_RX_PIN)
    #define SER_MOSI_SCL_RX_HSIOM_REG      SER_RX_SCL_MOSI_HSIOM_REG
    #define SER_MOSI_SCL_RX_HSIOM_PTR      SER_RX_SCL_MOSI_HSIOM_PTR
    #define SER_MOSI_SCL_RX_HSIOM_MASK     SER_RX_SCL_MOSI_HSIOM_MASK
    #define SER_MOSI_SCL_RX_HSIOM_POS      SER_RX_SCL_MOSI_HSIOM_POS
#endif /* (SER_MOSI_SCL_RX_PIN) */

#if (SER_MISO_SDA_TX_PIN)
    #define SER_MISO_SDA_TX_HSIOM_REG      SER_TX_SDA_MISO_HSIOM_REG
    #define SER_MISO_SDA_TX_HSIOM_PTR      SER_TX_SDA_MISO_HSIOM_REG
    #define SER_MISO_SDA_TX_HSIOM_MASK     SER_TX_SDA_MISO_HSIOM_REG
    #define SER_MISO_SDA_TX_HSIOM_POS      SER_TX_SDA_MISO_HSIOM_REG
#endif /* (SER_MISO_SDA_TX_PIN_PIN) */

#if (SER_SCLK_PIN)
    #ifndef SER_SCLK_HSIOM_REG
    #define SER_SCLK_HSIOM_REG     SER_SCLK_HSIOM_REG
    #define SER_SCLK_HSIOM_PTR     SER_SCLK_HSIOM_PTR
    #define SER_SCLK_HSIOM_MASK    SER_SCLK_HSIOM_MASK
    #define SER_SCLK_HSIOM_POS     SER_SCLK_HSIOM_POS
    #endif /* SER_SCLK_HSIOM_REG */
#endif /* (SER_SCLK_PIN) */

#if (SER_SS0_PIN)
    #ifndef SER_SS0_HSIOM_REG
    #define SER_SS0_HSIOM_REG      SER_SS0_HSIOM_REG
    #define SER_SS0_HSIOM_PTR      SER_SS0_HSIOM_PTR
    #define SER_SS0_HSIOM_MASK     SER_SS0_HSIOM_MASK
    #define SER_SS0_HSIOM_POS      SER_SS0_HSIOM_POS
    #endif /* SER_SS0_HSIOM_REG */
#endif /* (SER_SS0_PIN) */

#define SER_MOSI_SCL_RX_WAKE_PIN_INDEX SER_RX_WAKE_SCL_MOSI_PIN_INDEX
#define SER_MOSI_SCL_RX_PIN_INDEX      SER_RX_SCL_MOSI_PIN_INDEX
#define SER_MISO_SDA_TX_PIN_INDEX      SER_TX_SDA_MISO_PIN_INDEX
#ifndef SER_SCLK_PIN_INDEX
#define SER_SCLK_PIN_INDEX             SER_SCLK_PIN_INDEX
#endif /* SER_SCLK_PIN_INDEX */
#ifndef SER_SS0_PIN_INDEX
#define SER_SS0_PIN_INDEX              SER_SS0_PIN_INDEX
#endif /* SER_SS0_PIN_INDEX */

#define SER_MOSI_SCL_RX_WAKE_PIN_MASK SER_RX_WAKE_SCL_MOSI_PIN_MASK
#define SER_MOSI_SCL_RX_PIN_MASK      SER_RX_SCL_MOSI_PIN_MASK
#define SER_MISO_SDA_TX_PIN_MASK      SER_TX_SDA_MISO_PIN_MASK
#ifndef SER_SCLK_PIN_MASK
#define SER_SCLK_PIN_MASK             SER_SCLK_PIN_MASK
#endif /* SER_SCLK_PIN_MASK */
#ifndef SER_SS0_PIN_MASK
#define SER_SS0_PIN_MASK              SER_SS0_PIN_MASK
#endif /* SER_SS0_PIN_MASK */

#endif /* (CY_SCB_PINS_SER_H) */


/* [] END OF FILE */
