/*******************************************************************************
* File Name: SER_SCBCLK.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_SER_SCBCLK_H)
#define CY_CLOCK_SER_SCBCLK_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void SER_SCBCLK_StartEx(uint32 alignClkDiv);
#define SER_SCBCLK_Start() \
    SER_SCBCLK_StartEx(SER_SCBCLK__PA_DIV_ID)

#else

void SER_SCBCLK_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void SER_SCBCLK_Stop(void);

void SER_SCBCLK_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 SER_SCBCLK_GetDividerRegister(void);
uint8  SER_SCBCLK_GetFractionalDividerRegister(void);

#define SER_SCBCLK_Enable()                         SER_SCBCLK_Start()
#define SER_SCBCLK_Disable()                        SER_SCBCLK_Stop()
#define SER_SCBCLK_SetDividerRegister(clkDivider, reset)  \
    SER_SCBCLK_SetFractionalDividerRegister((clkDivider), 0u)
#define SER_SCBCLK_SetDivider(clkDivider)           SER_SCBCLK_SetDividerRegister((clkDivider), 1u)
#define SER_SCBCLK_SetDividerValue(clkDivider)      SER_SCBCLK_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define SER_SCBCLK_DIV_ID     SER_SCBCLK__DIV_ID

#define SER_SCBCLK_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define SER_SCBCLK_CTRL_REG   (*(reg32 *)SER_SCBCLK__CTRL_REGISTER)
#define SER_SCBCLK_DIV_REG    (*(reg32 *)SER_SCBCLK__DIV_REGISTER)

#define SER_SCBCLK_CMD_DIV_SHIFT          (0u)
#define SER_SCBCLK_CMD_PA_DIV_SHIFT       (8u)
#define SER_SCBCLK_CMD_DISABLE_SHIFT      (30u)
#define SER_SCBCLK_CMD_ENABLE_SHIFT       (31u)

#define SER_SCBCLK_CMD_DISABLE_MASK       ((uint32)((uint32)1u << SER_SCBCLK_CMD_DISABLE_SHIFT))
#define SER_SCBCLK_CMD_ENABLE_MASK        ((uint32)((uint32)1u << SER_SCBCLK_CMD_ENABLE_SHIFT))

#define SER_SCBCLK_DIV_FRAC_MASK  (0x000000F8u)
#define SER_SCBCLK_DIV_FRAC_SHIFT (3u)
#define SER_SCBCLK_DIV_INT_MASK   (0xFFFFFF00u)
#define SER_SCBCLK_DIV_INT_SHIFT  (8u)

#else 

#define SER_SCBCLK_DIV_REG        (*(reg32 *)SER_SCBCLK__REGISTER)
#define SER_SCBCLK_ENABLE_REG     SER_SCBCLK_DIV_REG
#define SER_SCBCLK_DIV_FRAC_MASK  SER_SCBCLK__FRAC_MASK
#define SER_SCBCLK_DIV_FRAC_SHIFT (16u)
#define SER_SCBCLK_DIV_INT_MASK   SER_SCBCLK__DIVIDER_MASK
#define SER_SCBCLK_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_SER_SCBCLK_H) */

/* [] END OF FILE */
