/*******************************************************************************
* File Name: SER_SPI_UART.h
* Version 3.0
*
* Description:
*  This file provides constants and parameter values for the SCB Component in
*  SPI and UART modes.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_SER_H)
#define CY_SCB_SPI_UART_SER_H

#include "SER.h"


/***************************************
*   SPI Initial Parameter Constants
****************************************/

#define SER_SPI_MODE                   (0u)
#define SER_SPI_SUB_MODE               (0u)
#define SER_SPI_CLOCK_MODE             (0u)
#define SER_SPI_OVS_FACTOR             (16u)
#define SER_SPI_MEDIAN_FILTER_ENABLE   (0u)
#define SER_SPI_LATE_MISO_SAMPLE_ENABLE (0u)
#define SER_SPI_RX_DATA_BITS_NUM       (8u)
#define SER_SPI_TX_DATA_BITS_NUM       (8u)
#define SER_SPI_WAKE_ENABLE            (0u)
#define SER_SPI_BITS_ORDER             (1u)
#define SER_SPI_TRANSFER_SEPARATION    (1u)
#define SER_SPI_NUMBER_OF_SS_LINES     (1u)
#define SER_SPI_RX_BUFFER_SIZE         (8u)
#define SER_SPI_TX_BUFFER_SIZE         (8u)

#define SER_SPI_INTERRUPT_MODE         (0u)

#define SER_SPI_INTR_RX_MASK           (0u)
#define SER_SPI_INTR_TX_MASK           (0u)

#define SER_SPI_RX_TRIGGER_LEVEL       (7u)
#define SER_SPI_TX_TRIGGER_LEVEL       (0u)

#define SER_SPI_BYTE_MODE_ENABLE       (0u)
#define SER_SPI_FREE_RUN_SCLK_ENABLE   (0u)
#define SER_SPI_SS0_POLARITY           (0u)
#define SER_SPI_SS1_POLARITY           (0u)
#define SER_SPI_SS2_POLARITY           (0u)
#define SER_SPI_SS3_POLARITY           (0u)


/***************************************
*   UART Initial Parameter Constants
****************************************/

#define SER_UART_SUB_MODE              (0u)
#define SER_UART_DIRECTION             (3u)
#define SER_UART_DATA_BITS_NUM         (8u)
#define SER_UART_PARITY_TYPE           (2u)
#define SER_UART_STOP_BITS_NUM         (2u)
#define SER_UART_OVS_FACTOR            (12u)
#define SER_UART_IRDA_LOW_POWER        (0u)
#define SER_UART_MEDIAN_FILTER_ENABLE  (0u)
#define SER_UART_RETRY_ON_NACK         (0u)
#define SER_UART_IRDA_POLARITY         (0u)
#define SER_UART_DROP_ON_FRAME_ERR     (0u)
#define SER_UART_DROP_ON_PARITY_ERR    (0u)
#define SER_UART_WAKE_ENABLE           (0u)
#define SER_UART_RX_BUFFER_SIZE        (10u)
#define SER_UART_TX_BUFFER_SIZE        (10u)
#define SER_UART_MP_MODE_ENABLE        (0u)
#define SER_UART_MP_ACCEPT_ADDRESS     (0u)
#define SER_UART_MP_RX_ADDRESS         (2u)
#define SER_UART_MP_RX_ADDRESS_MASK    (255u)

#define SER_UART_INTERRUPT_MODE        (1u)

#define SER_UART_INTR_RX_MASK          (5u)
#define SER_UART_INTR_TX_MASK          (0u)

#define SER_UART_RX_TRIGGER_LEVEL      (0u)
#define SER_UART_TX_TRIGGER_LEVEL      (0u)

#define SER_UART_BYTE_MODE_ENABLE      (0u)
#define SER_UART_CTS_ENABLE            (0u)
#define SER_UART_CTS_POLARITY          (0u)
#define SER_UART_RTS_ENABLE            (0u)
#define SER_UART_RTS_POLARITY          (0u)
#define SER_UART_RTS_FIFO_LEVEL        (4u)

/* SPI mode enum */
#define SER_SPI_SLAVE  (0u)
#define SER_SPI_MASTER (1u)

/* UART direction enum */
#define SER_UART_RX    (1u)
#define SER_UART_TX    (2u)
#define SER_UART_TX_RX (3u)


/***************************************
*   Conditional Compilation Parameters
****************************************/

#if(SER_SCB_MODE_UNCONFIG_CONST_CFG)

    /* Mode */
    #define SER_SPI_SLAVE_CONST        (1u)
    #define SER_SPI_MASTER_CONST       (1u)

    /* Direction */
    #define SER_RX_DIRECTION           (1u)
    #define SER_TX_DIRECTION           (1u)
    #define SER_UART_RX_DIRECTION      (1u)
    #define SER_UART_TX_DIRECTION      (1u)

    /* Only external RX and TX buffer for Uncofigured mode */
    #define SER_INTERNAL_RX_SW_BUFFER   (0u)
    #define SER_INTERNAL_TX_SW_BUFFER   (0u)

    /* Get RX and TX buffer size */
    #define SER_INTERNAL_RX_BUFFER_SIZE    (SER_rxBufferSize + 1u)
    #define SER_RX_BUFFER_SIZE             (SER_rxBufferSize)
    #define SER_TX_BUFFER_SIZE             (SER_txBufferSize)

    /* Return true if buffer is provided */
    #define SER_CHECK_RX_SW_BUFFER (NULL != SER_rxBuffer)
    #define SER_CHECK_TX_SW_BUFFER (NULL != SER_txBuffer)

    /* Always provide global variables to support RX and TX buffers */
    #define SER_INTERNAL_RX_SW_BUFFER_CONST    (1u)
    #define SER_INTERNAL_TX_SW_BUFFER_CONST    (1u)

    /* Get wakeup enable option */
    #define SER_SPI_WAKE_ENABLE_CONST  (1u)
    #define SER_CHECK_SPI_WAKE_ENABLE  (0u != SER_scbEnableWake)
    #define SER_UART_WAKE_ENABLE_CONST (1u)

    /* SPI/UART: TX or RX FIFO size */
    #if (SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1)
        #define SER_SPI_UART_FIFO_SIZE             (SER_FIFO_SIZE)
        #define SER_CHECK_UART_RTS_CONTROL_FLOW    (0u)
    #else
        #define SER_SPI_UART_FIFO_SIZE (SER_GET_FIFO_SIZE(SER_CTRL_REG & \
                                                                                    SER_CTRL_BYTE_MODE))

        #define SER_CHECK_UART_RTS_CONTROL_FLOW \
                    ((SER_SCB_MODE_UART_RUNTM_CFG) && \
                     (0u != SER_GET_UART_FLOW_CTRL_TRIGGER_LEVEL(SER_UART_FLOW_CTRL_REG)))
    #endif /* (SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1) */

#else

    /* Internal RX and TX buffer: for SPI or UART */
    #if (SER_SCB_MODE_SPI_CONST_CFG)

        /* SPI Direction */
        #define SER_SPI_RX_DIRECTION (1u)
        #define SER_SPI_TX_DIRECTION (1u)

        /* Get FIFO size */
        #if (SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1)
            #define SER_SPI_UART_FIFO_SIZE    (SER_FIFO_SIZE)
        #else
            #define SER_SPI_UART_FIFO_SIZE \
                                           SER_GET_FIFO_SIZE(SER_SPI_BYTE_MODE_ENABLE)

        #endif /* (SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1) */

        /* SPI internal RX and TX buffers */
        #define SER_INTERNAL_SPI_RX_SW_BUFFER  (SER_SPI_RX_BUFFER_SIZE > \
                                                                SER_SPI_UART_FIFO_SIZE)
        #define SER_INTERNAL_SPI_TX_SW_BUFFER  (SER_SPI_TX_BUFFER_SIZE > \
                                                                SER_SPI_UART_FIFO_SIZE)

        /* Internal SPI RX and TX buffer */
        #define SER_INTERNAL_RX_SW_BUFFER  (SER_INTERNAL_SPI_RX_SW_BUFFER)
        #define SER_INTERNAL_TX_SW_BUFFER  (SER_INTERNAL_SPI_TX_SW_BUFFER)

        /* Internal SPI RX and TX buffer size */
        #define SER_INTERNAL_RX_BUFFER_SIZE    (SER_SPI_RX_BUFFER_SIZE + 1u)
        #define SER_RX_BUFFER_SIZE             (SER_SPI_RX_BUFFER_SIZE)
        #define SER_TX_BUFFER_SIZE             (SER_SPI_TX_BUFFER_SIZE)

        /* Get wakeup enable option */
        #define SER_SPI_WAKE_ENABLE_CONST  (0u != SER_SPI_WAKE_ENABLE)
        #define SER_UART_WAKE_ENABLE_CONST (0u)

    #else

        /* UART Direction */
        #define SER_UART_RX_DIRECTION (0u != (SER_UART_DIRECTION & SER_UART_RX))
        #define SER_UART_TX_DIRECTION (0u != (SER_UART_DIRECTION & SER_UART_TX))

        /* Get FIFO size */
        #if (SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1)
            #define SER_SPI_UART_FIFO_SIZE    (SER_FIFO_SIZE)
        #else
            #define SER_SPI_UART_FIFO_SIZE \
                                           SER_GET_FIFO_SIZE(SER_UART_BYTE_MODE_ENABLE)
        #endif /* (SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1) */

        /* UART internal RX and TX buffers */
        #define SER_INTERNAL_UART_RX_SW_BUFFER  (SER_UART_RX_BUFFER_SIZE > \
                                                                SER_SPI_UART_FIFO_SIZE)
        #define SER_INTERNAL_UART_TX_SW_BUFFER  (SER_UART_TX_BUFFER_SIZE > \
                                                                    SER_SPI_UART_FIFO_SIZE)

        /* Internal UART RX and TX buffer */
        #define SER_INTERNAL_RX_SW_BUFFER  (SER_INTERNAL_UART_RX_SW_BUFFER)
        #define SER_INTERNAL_TX_SW_BUFFER  (SER_INTERNAL_UART_TX_SW_BUFFER)

        /* Internal UART RX and TX buffer size */
        #define SER_INTERNAL_RX_BUFFER_SIZE    (SER_UART_RX_BUFFER_SIZE + 1u)
        #define SER_RX_BUFFER_SIZE             (SER_UART_RX_BUFFER_SIZE)
        #define SER_TX_BUFFER_SIZE             (SER_UART_TX_BUFFER_SIZE)

        /* Get wakeup enable option */
        #define SER_SPI_WAKE_ENABLE_CONST  (0u)
        #define SER_UART_WAKE_ENABLE_CONST (0u != SER_UART_WAKE_ENABLE)

    #endif /* (SER_SCB_MODE_SPI_CONST_CFG) */

    /* Mode */
    #define SER_SPI_SLAVE_CONST    (SER_SPI_MODE == SER_SPI_SLAVE)
    #define SER_SPI_MASTER_CONST   (SER_SPI_MODE == SER_SPI_MASTER)

    /* Direction */
    #define SER_RX_DIRECTION ((SER_SCB_MODE_SPI_CONST_CFG) ? \
                                            (SER_SPI_RX_DIRECTION) : (SER_UART_RX_DIRECTION))

    #define SER_TX_DIRECTION ((SER_SCB_MODE_SPI_CONST_CFG) ? \
                                            (SER_SPI_TX_DIRECTION) : (SER_UART_TX_DIRECTION))

    /* Internal RX and TX buffer: for SPI or UART. Used in conditional compilation check */
    #define SER_CHECK_RX_SW_BUFFER (SER_INTERNAL_RX_SW_BUFFER)
    #define SER_CHECK_TX_SW_BUFFER (SER_INTERNAL_TX_SW_BUFFER)

    /* Provide global variables to support RX and TX buffers */
    #define SER_INTERNAL_RX_SW_BUFFER_CONST    (SER_INTERNAL_RX_SW_BUFFER)
    #define SER_INTERNAL_TX_SW_BUFFER_CONST    (SER_INTERNAL_TX_SW_BUFFER)

    /* SPI wakeup */
    #define SER_CHECK_SPI_WAKE_ENABLE  (SER_SPI_WAKE_ENABLE_CONST)

    /* UART flow control: not applicable for CY_SCBIP_V0 || CY_SCBIP_V1 */
    #define SER_CHECK_UART_RTS_CONTROL_FLOW    (SER_SCB_MODE_UART_CONST_CFG && \
                                                             SER_UART_RTS_ENABLE)

#endif /* End (SER_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*       Type Definitions
***************************************/

/* SER_SPI_INIT_STRUCT */
typedef struct
{
    uint32 mode;
    uint32 submode;
    uint32 sclkMode;
    uint32 oversample;
    uint32 enableMedianFilter;
    uint32 enableLateSampling;
    uint32 enableWake;
    uint32 rxDataBits;
    uint32 txDataBits;
    uint32 bitOrder;
    uint32 transferSeperation;
    uint32 rxBufferSize;
    uint8* rxBuffer;
    uint32 txBufferSize;
    uint8* txBuffer;
    uint32 enableInterrupt;
    uint32 rxInterruptMask;
    uint32 rxTriggerLevel;
    uint32 txInterruptMask;
    uint32 txTriggerLevel;
    uint8 enableByteMode;
    uint8 enableFreeRunSclk;
    uint8 polaritySs;
} SER_SPI_INIT_STRUCT;

/* SER_UART_INIT_STRUCT */
typedef struct
{
    uint32 mode;
    uint32 direction;
    uint32 dataBits;
    uint32 parity;
    uint32 stopBits;
    uint32 oversample;
    uint32 enableIrdaLowPower;
    uint32 enableMedianFilter;
    uint32 enableRetryNack;
    uint32 enableInvertedRx;
    uint32 dropOnParityErr;
    uint32 dropOnFrameErr;
    uint32 enableWake;
    uint32 rxBufferSize;
    uint8* rxBuffer;
    uint32 txBufferSize;
    uint8* txBuffer;
    uint32 enableMultiproc;
    uint32 multiprocAcceptAddr;
    uint32 multiprocAddr;
    uint32 multiprocAddrMask;
    uint32 enableInterrupt;
    uint32 rxInterruptMask;
    uint32 rxTriggerLevel;
    uint32 txInterruptMask;
    uint32 txTriggerLevel;
    uint8 enableByteMode;
    uint8 enableCts;
    uint8 ctsPolarity;
    uint8 rtsRxFifoLevel;
    uint8 rtsPolarity;
} SER_UART_INIT_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

/* SPI specific functions */
#if(SER_SCB_MODE_UNCONFIG_CONST_CFG)
    void SER_SpiInit(const SER_SPI_INIT_STRUCT *config);
#endif /* (SER_SCB_MODE_UNCONFIG_CONST_CFG) */

#if(SER_SCB_MODE_SPI_INC)
    #define SER_SpiIsBusBusy() ((uint32) (0u != (SER_SPI_STATUS_REG & \
                                                              SER_SPI_STATUS_BUS_BUSY)))

    #if (SER_SPI_MASTER_CONST)
        void SER_SpiSetActiveSlaveSelect(uint32 slaveSelect);
    #endif /*(SER_SPI_MASTER_CONST) */

    #if !(SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1)
        void SER_SpiSetSlaveSelectPolarity(uint32 slaveSelect, uint32 polarity);
    #endif /* !(SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1) */
#endif /* (SER_SCB_MODE_SPI_INC) */

/* UART specific functions */
#if(SER_SCB_MODE_UNCONFIG_CONST_CFG)
    void SER_UartInit(const SER_UART_INIT_STRUCT *config);
#endif /* (SER_SCB_MODE_UNCONFIG_CONST_CFG) */

#if(SER_SCB_MODE_UART_INC)
    void SER_UartSetRxAddress(uint32 address);
    void SER_UartSetRxAddressMask(uint32 addressMask);

    /* UART RX direction APIs */
    #if(SER_UART_RX_DIRECTION)
        uint32 SER_UartGetChar(void);
        uint32 SER_UartGetByte(void);

        #if !(SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1)
            /* UART APIs for Flow Control */
            void SER_UartSetRtsPolarity(uint32 polarity);
            void SER_UartSetRtsFifoLevel(uint32 level);
        #endif /* !(SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1) */
    #endif /* (SER_UART_RX_DIRECTION) */

    /* UART TX direction APIs */
    #if(SER_UART_TX_DIRECTION)
        #define SER_UartPutChar(ch)    SER_SpiUartWriteTxData((uint32)(ch))
        void SER_UartPutString(const char8 string[]);
        void SER_UartPutCRLF(uint32 txDataByte);

        #if !(SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1)
            /* UART APIs for Flow Control */
            void SER_UartEnableCts(void);
            void SER_UartDisableCts(void);
            void SER_UartSetCtsPolarity(uint32 polarity);
        #endif /* !(SER_CY_SCBIP_V0 || SER_CY_SCBIP_V1) */
    #endif /* (SER_UART_TX_DIRECTION) */
#endif /* (SER_SCB_MODE_UART_INC) */

/* Common APIs RX direction */
#if(SER_RX_DIRECTION)
    uint32 SER_SpiUartReadRxData(void);
    uint32 SER_SpiUartGetRxBufferSize(void);
    void   SER_SpiUartClearRxBuffer(void);
#endif /* (SER_RX_DIRECTION) */

/* Common APIs TX direction */
#if(SER_TX_DIRECTION)
    void   SER_SpiUartWriteTxData(uint32 txData);
    void   SER_SpiUartPutArray(const uint8 wrBuf[], uint32 count);
    uint32 SER_SpiUartGetTxBufferSize(void);
    void   SER_SpiUartClearTxBuffer(void);
#endif /* (SER_TX_DIRECTION) */

CY_ISR_PROTO(SER_SPI_UART_ISR);

#if(SER_UART_RX_WAKEUP_IRQ)
    CY_ISR_PROTO(SER_UART_WAKEUP_ISR);
#endif /* (SER_UART_RX_WAKEUP_IRQ) */


/***************************************
*     Buffer Access Macro Definitions
***************************************/

#if(SER_SCB_MODE_UNCONFIG_CONST_CFG)
    /* RX direction */
    void   SER_PutWordInRxBuffer  (uint32 idx, uint32 rxDataByte);
    uint32 SER_GetWordFromRxBuffer(uint32 idx);

    /* TX direction */
    void   SER_PutWordInTxBuffer  (uint32 idx, uint32 txDataByte);
    uint32 SER_GetWordFromTxBuffer(uint32 idx);

#else
    /* RX direction */
    #if(SER_INTERNAL_RX_SW_BUFFER_CONST)
        #define SER_PutWordInRxBuffer(idx, rxDataByte) \
                do{                                                 \
                    SER_rxBufferInternal[(idx)] = ((uint8) (rxDataByte)); \
                }while(0)

        #define SER_GetWordFromRxBuffer(idx) SER_rxBufferInternal[(idx)]

    #endif /* (SER_INTERNAL_RX_SW_BUFFER_CONST) */

    /* TX direction */
    #if(SER_INTERNAL_TX_SW_BUFFER_CONST)
        #define SER_PutWordInTxBuffer(idx, txDataByte) \
                    do{                                             \
                        SER_txBufferInternal[(idx)] = ((uint8) (txDataByte)); \
                    }while(0)

        #define SER_GetWordFromTxBuffer(idx) SER_txBufferInternal[(idx)]

    #endif /* (SER_INTERNAL_TX_SW_BUFFER_CONST) */

#endif /* (SER_TX_SW_BUFFER_ENABLE) */


/***************************************
*         SPI API Constants
***************************************/

/* SPI sub mode enum */
#define SER_SPI_MODE_MOTOROLA      (0x00u)
#define SER_SPI_MODE_TI_COINCIDES  (0x01u)
#define SER_SPI_MODE_TI_PRECEDES   (0x11u)
#define SER_SPI_MODE_NATIONAL      (0x02u)
#define SER_SPI_MODE_MASK          (0x03u)
#define SER_SPI_MODE_TI_PRECEDES_MASK  (0x10u)
#define SER_SPI_MODE_NS_MICROWIRE  (SER_SPI_MODE_NATIONAL)

/* SPI phase and polarity mode enum */
#define SER_SPI_SCLK_CPHA0_CPOL0   (0x00u)
#define SER_SPI_SCLK_CPHA0_CPOL1   (0x02u)
#define SER_SPI_SCLK_CPHA1_CPOL0   (0x01u)
#define SER_SPI_SCLK_CPHA1_CPOL1   (0x03u)

/* SPI bits order enum */
#define SER_BITS_ORDER_LSB_FIRST   (0u)
#define SER_BITS_ORDER_MSB_FIRST   (1u)

/* SPI transfer separation enum */
#define SER_SPI_TRANSFER_SEPARATED     (0u)
#define SER_SPI_TRANSFER_CONTINUOUS    (1u)

/* SPI slave select constants */
#define SER_SPI_SLAVE_SELECT0    (SER_SCB__SS0_POSISTION)
#define SER_SPI_SLAVE_SELECT1    (SER_SCB__SS1_POSISTION)
#define SER_SPI_SLAVE_SELECT2    (SER_SCB__SS2_POSISTION)
#define SER_SPI_SLAVE_SELECT3    (SER_SCB__SS3_POSISTION)

/* SPI slave select polarity settings */
#define SER_SPI_SS_ACTIVE_LOW  (0u)
#define SER_SPI_SS_ACTIVE_HIGH (1u)


/***************************************
*         UART API Constants
***************************************/

/* UART sub-modes enum */
#define SER_UART_MODE_STD          (0u)
#define SER_UART_MODE_SMARTCARD    (1u)
#define SER_UART_MODE_IRDA         (2u)

/* UART direction enum */
#define SER_UART_RX    (1u)
#define SER_UART_TX    (2u)
#define SER_UART_TX_RX (3u)

/* UART parity enum */
#define SER_UART_PARITY_EVEN   (0u)
#define SER_UART_PARITY_ODD    (1u)
#define SER_UART_PARITY_NONE   (2u)

/* UART stop bits enum */
#define SER_UART_STOP_BITS_1   (2u)
#define SER_UART_STOP_BITS_1_5 (3u)
#define SER_UART_STOP_BITS_2   (4u)

/* UART IrDA low power OVS enum */
#define SER_UART_IRDA_LP_OVS16     (16u)
#define SER_UART_IRDA_LP_OVS32     (32u)
#define SER_UART_IRDA_LP_OVS48     (48u)
#define SER_UART_IRDA_LP_OVS96     (96u)
#define SER_UART_IRDA_LP_OVS192    (192u)
#define SER_UART_IRDA_LP_OVS768    (768u)
#define SER_UART_IRDA_LP_OVS1536   (1536u)

/* Uart MP: mark (address) and space (data) bit definitions */
#define SER_UART_MP_MARK       (0x100u)
#define SER_UART_MP_SPACE      (0x000u)

/* UART CTS/RTS polarity settings */
#define SER_UART_CTS_ACTIVE_LOW    (0u)
#define SER_UART_CTS_ACTIVE_HIGH   (1u)
#define SER_UART_RTS_ACTIVE_LOW    (0u)
#define SER_UART_RTS_ACTIVE_HIGH   (1u)

/* Sources of RX errors */
#define SER_INTR_RX_ERR        (SER_INTR_RX_OVERFLOW    | \
                                             SER_INTR_RX_UNDERFLOW   | \
                                             SER_INTR_RX_FRAME_ERROR | \
                                             SER_INTR_RX_PARITY_ERROR)

/* Shifted INTR_RX_ERR defines ONLY for SER_UartGetByte() */
#define SER_UART_RX_OVERFLOW       (SER_INTR_RX_OVERFLOW << 8u)
#define SER_UART_RX_UNDERFLOW      (SER_INTR_RX_UNDERFLOW << 8u)
#define SER_UART_RX_FRAME_ERROR    (SER_INTR_RX_FRAME_ERROR << 8u)
#define SER_UART_RX_PARITY_ERROR   (SER_INTR_RX_PARITY_ERROR << 8u)
#define SER_UART_RX_ERROR_MASK     (SER_UART_RX_OVERFLOW    | \
                                                 SER_UART_RX_UNDERFLOW   | \
                                                 SER_UART_RX_FRAME_ERROR | \
                                                 SER_UART_RX_PARITY_ERROR)


/***************************************
*     Vars with External Linkage
***************************************/

#if(SER_SCB_MODE_UNCONFIG_CONST_CFG)
    extern const SER_SPI_INIT_STRUCT  SER_configSpi;
    extern const SER_UART_INIT_STRUCT SER_configUart;
#endif /* (SER_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*    Specific SPI Macro Definitions
***************************************/

#define SER_GET_SPI_INTR_SLAVE_MASK(sourceMask)  ((sourceMask) & SER_INTR_SLAVE_SPI_BUS_ERROR)
#define SER_GET_SPI_INTR_MASTER_MASK(sourceMask) ((sourceMask) & SER_INTR_MASTER_SPI_DONE)
#define SER_GET_SPI_INTR_RX_MASK(sourceMask) \
                                             ((sourceMask) & (uint32) ~SER_INTR_SLAVE_SPI_BUS_ERROR)

#define SER_GET_SPI_INTR_TX_MASK(sourceMask) \
                                             ((sourceMask) & (uint32) ~SER_INTR_MASTER_SPI_DONE)


/***************************************
*    Specific UART Macro Definitions
***************************************/

#define SER_UART_GET_CTRL_OVS_IRDA_LP(oversample) \
        ((SER_UART_IRDA_LP_OVS16   == (oversample)) ? SER_CTRL_OVS_IRDA_LP_OVS16 : \
         ((SER_UART_IRDA_LP_OVS32   == (oversample)) ? SER_CTRL_OVS_IRDA_LP_OVS32 : \
          ((SER_UART_IRDA_LP_OVS48   == (oversample)) ? SER_CTRL_OVS_IRDA_LP_OVS48 : \
           ((SER_UART_IRDA_LP_OVS96   == (oversample)) ? SER_CTRL_OVS_IRDA_LP_OVS96 : \
            ((SER_UART_IRDA_LP_OVS192  == (oversample)) ? SER_CTRL_OVS_IRDA_LP_OVS192 : \
             ((SER_UART_IRDA_LP_OVS768  == (oversample)) ? SER_CTRL_OVS_IRDA_LP_OVS768 : \
              ((SER_UART_IRDA_LP_OVS1536 == (oversample)) ? SER_CTRL_OVS_IRDA_LP_OVS1536 : \
                                                                          SER_CTRL_OVS_IRDA_LP_OVS16)))))))

#define SER_GET_UART_RX_CTRL_ENABLED(direction) ((0u != (SER_UART_RX & (direction))) ? \
                                                                     (SER_RX_CTRL_ENABLED) : (0u))

#define SER_GET_UART_TX_CTRL_ENABLED(direction) ((0u != (SER_UART_TX & (direction))) ? \
                                                                     (SER_TX_CTRL_ENABLED) : (0u))


/***************************************
*        SPI Register Settings
***************************************/

#define SER_CTRL_SPI      (SER_CTRL_MODE_SPI)
#define SER_SPI_RX_CTRL   (SER_RX_CTRL_ENABLED)
#define SER_SPI_TX_CTRL   (SER_TX_CTRL_ENABLED)


/***************************************
*       SPI Init Register Settings
***************************************/

#define SER_SPI_SS_POLARITY \
             (((uint32) SER_SPI_SS0_POLARITY << SER_SPI_SLAVE_SELECT0) | \
              ((uint32) SER_SPI_SS1_POLARITY << SER_SPI_SLAVE_SELECT1) | \
              ((uint32) SER_SPI_SS2_POLARITY << SER_SPI_SLAVE_SELECT2) | \
              ((uint32) SER_SPI_SS3_POLARITY << SER_SPI_SLAVE_SELECT3))

#if(SER_SCB_MODE_SPI_CONST_CFG)

    /* SPI Configuration */
    #define SER_SPI_DEFAULT_CTRL \
                    (SER_GET_CTRL_OVS(SER_SPI_OVS_FACTOR) | \
                     SER_GET_CTRL_BYTE_MODE (SER_SPI_BYTE_MODE_ENABLE) | \
                     SER_GET_CTRL_EC_AM_MODE(SER_SPI_WAKE_ENABLE)      | \
                     SER_CTRL_SPI)

    #define SER_SPI_DEFAULT_SPI_CTRL \
                    (SER_GET_SPI_CTRL_CONTINUOUS    (SER_SPI_TRANSFER_SEPARATION)       | \
                     SER_GET_SPI_CTRL_SELECT_PRECEDE(SER_SPI_SUB_MODE &                   \
                                                                  SER_SPI_MODE_TI_PRECEDES_MASK)     | \
                     SER_GET_SPI_CTRL_SCLK_MODE     (SER_SPI_CLOCK_MODE)                | \
                     SER_GET_SPI_CTRL_LATE_MISO_SAMPLE(SER_SPI_LATE_MISO_SAMPLE_ENABLE) | \
                     SER_GET_SPI_CTRL_SCLK_CONTINUOUS(SER_SPI_FREE_RUN_SCLK_ENABLE)     | \
                     SER_GET_SPI_CTRL_SSEL_POLARITY (SER_SPI_SS_POLARITY)               | \
                     SER_GET_SPI_CTRL_SUB_MODE      (SER_SPI_SUB_MODE)                  | \
                     SER_GET_SPI_CTRL_MASTER_MODE   (SER_SPI_MODE))

    /* RX direction */
    #define SER_SPI_DEFAULT_RX_CTRL \
                    (SER_GET_RX_CTRL_DATA_WIDTH(SER_SPI_RX_DATA_BITS_NUM)     | \
                     SER_GET_RX_CTRL_BIT_ORDER (SER_SPI_BITS_ORDER)           | \
                     SER_GET_RX_CTRL_MEDIAN    (SER_SPI_MEDIAN_FILTER_ENABLE) | \
                     SER_SPI_RX_CTRL)

    #define SER_SPI_DEFAULT_RX_FIFO_CTRL \
                    SER_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(SER_SPI_RX_TRIGGER_LEVEL)

    /* TX direction */
    #define SER_SPI_DEFAULT_TX_CTRL \
                    (SER_GET_TX_CTRL_DATA_WIDTH(SER_SPI_TX_DATA_BITS_NUM) | \
                     SER_GET_TX_CTRL_BIT_ORDER (SER_SPI_BITS_ORDER)       | \
                     SER_SPI_TX_CTRL)

    #define SER_SPI_DEFAULT_TX_FIFO_CTRL \
                    SER_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(SER_SPI_TX_TRIGGER_LEVEL)

    /* Interrupt sources */
    #define SER_SPI_DEFAULT_INTR_SPI_EC_MASK   (SER_NO_INTR_SOURCES)

    #define SER_SPI_DEFAULT_INTR_I2C_EC_MASK   (SER_NO_INTR_SOURCES)
    #define SER_SPI_DEFAULT_INTR_SLAVE_MASK \
                    (SER_SPI_INTR_RX_MASK & SER_INTR_SLAVE_SPI_BUS_ERROR)

    #define SER_SPI_DEFAULT_INTR_MASTER_MASK \
                    (SER_SPI_INTR_TX_MASK & SER_INTR_MASTER_SPI_DONE)

    #define SER_SPI_DEFAULT_INTR_RX_MASK \
                    (SER_SPI_INTR_RX_MASK & (uint32) ~SER_INTR_SLAVE_SPI_BUS_ERROR)

    #define SER_SPI_DEFAULT_INTR_TX_MASK \
                    (SER_SPI_INTR_TX_MASK & (uint32) ~SER_INTR_MASTER_SPI_DONE)

#endif /* (SER_SCB_MODE_SPI_CONST_CFG) */


/***************************************
*        UART Register Settings
***************************************/

#define SER_CTRL_UART      (SER_CTRL_MODE_UART)
#define SER_UART_RX_CTRL   (SER_RX_CTRL_LSB_FIRST) /* LSB for UART goes first */
#define SER_UART_TX_CTRL   (SER_TX_CTRL_LSB_FIRST) /* LSB for UART goes first */


/***************************************
*      UART Init Register Settings
***************************************/

#if(SER_SCB_MODE_UART_CONST_CFG)

    /* UART configuration */
    #if(SER_UART_MODE_IRDA == SER_UART_SUB_MODE)

        #define SER_DEFAULT_CTRL_OVS   ((0u != SER_UART_IRDA_LOW_POWER) ?              \
                                (SER_UART_GET_CTRL_OVS_IRDA_LP(SER_UART_OVS_FACTOR)) : \
                                (SER_CTRL_OVS_IRDA_OVS16))

    #else

        #define SER_DEFAULT_CTRL_OVS   SER_GET_CTRL_OVS(SER_UART_OVS_FACTOR)

    #endif /* (SER_UART_MODE_IRDA == SER_UART_SUB_MODE) */

    #define SER_UART_DEFAULT_CTRL \
                                (SER_GET_CTRL_BYTE_MODE  (SER_UART_BYTE_MODE_ENABLE)  | \
                                 SER_GET_CTRL_ADDR_ACCEPT(SER_UART_MP_ACCEPT_ADDRESS) | \
                                 SER_DEFAULT_CTRL_OVS                                              | \
                                 SER_CTRL_UART)

    #define SER_UART_DEFAULT_UART_CTRL \
                                    (SER_GET_UART_CTRL_MODE(SER_UART_SUB_MODE))

    /* RX direction */
    #define SER_UART_DEFAULT_RX_CTRL_PARITY \
                                ((SER_UART_PARITY_NONE != SER_UART_PARITY_TYPE) ?      \
                                  (SER_GET_UART_RX_CTRL_PARITY(SER_UART_PARITY_TYPE) | \
                                   SER_UART_RX_CTRL_PARITY_ENABLED) : (0u))

    #define SER_UART_DEFAULT_UART_RX_CTRL \
                    (SER_GET_UART_RX_CTRL_MODE(SER_UART_STOP_BITS_NUM)                    | \
                     SER_GET_UART_RX_CTRL_POLARITY(SER_UART_IRDA_POLARITY)                | \
                     SER_GET_UART_RX_CTRL_MP_MODE(SER_UART_MP_MODE_ENABLE)                | \
                     SER_GET_UART_RX_CTRL_DROP_ON_PARITY_ERR(SER_UART_DROP_ON_PARITY_ERR) | \
                     SER_GET_UART_RX_CTRL_DROP_ON_FRAME_ERR(SER_UART_DROP_ON_FRAME_ERR)   | \
                     SER_UART_DEFAULT_RX_CTRL_PARITY)

    #define SER_UART_DEFAULT_RX_CTRL \
                                (SER_GET_RX_CTRL_DATA_WIDTH(SER_UART_DATA_BITS_NUM)        | \
                                 SER_GET_RX_CTRL_MEDIAN    (SER_UART_MEDIAN_FILTER_ENABLE) | \
                                 SER_GET_UART_RX_CTRL_ENABLED(SER_UART_DIRECTION))

    #define SER_UART_DEFAULT_RX_FIFO_CTRL \
                                SER_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(SER_UART_RX_TRIGGER_LEVEL)

    #define SER_UART_DEFAULT_RX_MATCH_REG  ((0u != SER_UART_MP_MODE_ENABLE) ?          \
                                (SER_GET_RX_MATCH_ADDR(SER_UART_MP_RX_ADDRESS) | \
                                 SER_GET_RX_MATCH_MASK(SER_UART_MP_RX_ADDRESS_MASK)) : (0u))

    /* TX direction */
    #define SER_UART_DEFAULT_TX_CTRL_PARITY (SER_UART_DEFAULT_RX_CTRL_PARITY)

    #define SER_UART_DEFAULT_UART_TX_CTRL \
                                (SER_GET_UART_TX_CTRL_MODE(SER_UART_STOP_BITS_NUM)       | \
                                 SER_GET_UART_TX_CTRL_RETRY_NACK(SER_UART_RETRY_ON_NACK) | \
                                 SER_UART_DEFAULT_TX_CTRL_PARITY)

    #define SER_UART_DEFAULT_TX_CTRL \
                                (SER_GET_TX_CTRL_DATA_WIDTH(SER_UART_DATA_BITS_NUM) | \
                                 SER_GET_UART_TX_CTRL_ENABLED(SER_UART_DIRECTION))

    #define SER_UART_DEFAULT_TX_FIFO_CTRL \
                                SER_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(SER_UART_TX_TRIGGER_LEVEL)

    #define SER_UART_DEFAULT_FLOW_CTRL \
                        (SER_GET_UART_FLOW_CTRL_TRIGGER_LEVEL(SER_UART_RTS_FIFO_LEVEL) | \
                         SER_GET_UART_FLOW_CTRL_RTS_POLARITY (SER_UART_RTS_POLARITY)   | \
                         SER_GET_UART_FLOW_CTRL_CTS_POLARITY (SER_UART_CTS_POLARITY)   | \
                         SER_GET_UART_FLOW_CTRL_CTS_ENABLE   (SER_UART_CTS_ENABLE))

    /* Interrupt sources */
    #define SER_UART_DEFAULT_INTR_I2C_EC_MASK  (SER_NO_INTR_SOURCES)
    #define SER_UART_DEFAULT_INTR_SPI_EC_MASK  (SER_NO_INTR_SOURCES)
    #define SER_UART_DEFAULT_INTR_SLAVE_MASK   (SER_NO_INTR_SOURCES)
    #define SER_UART_DEFAULT_INTR_MASTER_MASK  (SER_NO_INTR_SOURCES)
    #define SER_UART_DEFAULT_INTR_RX_MASK      (SER_UART_INTR_RX_MASK)
    #define SER_UART_DEFAULT_INTR_TX_MASK      (SER_UART_INTR_TX_MASK)

#endif /* (SER_SCB_MODE_UART_CONST_CFG) */


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

#define SER_SPIM_ACTIVE_SS0    (SER_SPI_SLAVE_SELECT0)
#define SER_SPIM_ACTIVE_SS1    (SER_SPI_SLAVE_SELECT1)
#define SER_SPIM_ACTIVE_SS2    (SER_SPI_SLAVE_SELECT2)
#define SER_SPIM_ACTIVE_SS3    (SER_SPI_SLAVE_SELECT3)

#endif /* CY_SCB_SPI_UART_SER_H */


/* [] END OF FILE */
