/*******************************************************************************
* File Name: SER_SPI_UART_PVT.h
* Version 3.0
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component in SPI and UART modes.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_PVT_SER_H)
#define CY_SCB_SPI_UART_PVT_SER_H

#include "SER_SPI_UART.h"


/***************************************
*     Internal Global Vars
***************************************/

#if (SER_INTERNAL_RX_SW_BUFFER_CONST)
    extern volatile uint32  SER_rxBufferHead;
    extern volatile uint32  SER_rxBufferTail;
    extern volatile uint8   SER_rxBufferOverflow;
#endif /* (SER_INTERNAL_RX_SW_BUFFER_CONST) */

#if (SER_INTERNAL_TX_SW_BUFFER_CONST)
    extern volatile uint32  SER_txBufferHead;
    extern volatile uint32  SER_txBufferTail;
#endif /* (SER_INTERNAL_TX_SW_BUFFER_CONST) */

#if (SER_INTERNAL_RX_SW_BUFFER)
    extern volatile uint8 SER_rxBufferInternal[SER_INTERNAL_RX_BUFFER_SIZE];
#endif /* (SER_INTERNAL_RX_SW_BUFFER) */

#if (SER_INTERNAL_TX_SW_BUFFER)
    extern volatile uint8 SER_txBufferInternal[SER_TX_BUFFER_SIZE];
#endif /* (SER_INTERNAL_TX_SW_BUFFER) */


/***************************************
*     Private Function Prototypes
***************************************/

void SER_SpiPostEnable(void);
void SER_SpiStop(void);

#if (SER_SCB_MODE_SPI_CONST_CFG)
    void SER_SpiInit(void);
#endif /* (SER_SCB_MODE_SPI_CONST_CFG) */

#if (SER_SPI_WAKE_ENABLE_CONST)
    void SER_SpiSaveConfig(void);
    void SER_SpiRestoreConfig(void);
#endif /* (SER_SPI_WAKE_ENABLE_CONST) */

void SER_UartPostEnable(void);
void SER_UartStop(void);

#if (SER_SCB_MODE_UART_CONST_CFG)
    void SER_UartInit(void);
#endif /* (SER_SCB_MODE_UART_CONST_CFG) */

#if (SER_UART_WAKE_ENABLE_CONST)
    void SER_UartSaveConfig(void);
    void SER_UartRestoreConfig(void);
#endif /* (SER_UART_WAKE_ENABLE_CONST) */


/***************************************
*         UART API Constants
***************************************/

/* UART RX and TX position to be used in SER_SetPins() */
#define SER_UART_RX_PIN_ENABLE    (SER_UART_RX)
#define SER_UART_TX_PIN_ENABLE    (SER_UART_TX)

/* UART RTS and CTS position to be used in  SER_SetPins() */
#define SER_UART_RTS_PIN_ENABLE    (0x10u)
#define SER_UART_CTS_PIN_ENABLE    (0x20u)


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Interrupt processing */
#define SER_SpiUartEnableIntRx(intSourceMask)  SER_SetRxInterruptMode(intSourceMask)
#define SER_SpiUartEnableIntTx(intSourceMask)  SER_SetTxInterruptMode(intSourceMask)
uint32  SER_SpiUartDisableIntRx(void);
uint32  SER_SpiUartDisableIntTx(void);


#endif /* (CY_SCB_SPI_UART_PVT_SER_H) */


/* [] END OF FILE */
